@@ -85,17 +85,18 @@ class Stats(BaseModel):
     count: int
 
 
-class HeightType(str, Enum):
-    """
-    Are the result chunks split by the height dimension or combined?
-    """
-    combined = 'combined'
-    split = 'split'
+# class HeightType(str, Enum):
+#     """
+#     Are the result chunks split by the height dimension or combined?
+#     """
+#     combined = 'combined'
+#     split = 'split'
 
 
 class ChunkParams(BaseModel):
-    time_interval: str = Field(None, description='The chunk time interval in the form of a Pandas frequency string (e.g. 1D, 7D). The mininum time interval should be 1D. A value of None indicates that there is no chunking along the time axis.')
-    height_type: HeightType
+    geometry_count: conint(gt=0) = Field(..., description='The number of geometries that should be chunked together. If the result_type is grid, then the geometry_count must be the square of another number. I.e. it must represent the area calc of a square (length * length).')
+    time_interval: conint(gt=0) = Field(None, description='The chunk time interval is the number of days the time chunk should cover (e.g. 365 would be about a year). A value of None indicates that there is no chunking along the time axis.')
+    height_interval: conint(gt=0) = Field(None, description='The chunk height interval is the interval of height indeces that the height should be chunked. A value of None indicates that there is no chunking along the height axis.')
 
 
 class ResultChunk(BaseModel):
@@ -105,7 +106,7 @@ class ResultChunk(BaseModel):
     chunk_id: str
     key: str
     bucket: str
-    content_length: int
+    content_length: conint(gt=0)
     etag: str
     heights: Union[List[float], List[int]]
     time_range: TimeRange = Field(..., description='The maximum time range of the result chunk.')
@@ -117,7 +118,7 @@ class ResultVersion(BaseModel):
     """
     version_date: datetime = Field(..., description='The date that uniquely defines this results version of the dataset and station.')
     name: str = None
-    content_length: int
+    content_length: conint(gt=0)
     doi: str = None
     description: str = Field(None, description='Description of the results version.')
     result_chunks: List[ResultChunk]
@@ -198,11 +199,11 @@ class Dataset(DatasetBase):
     precision: float = Field(None, description='The decimal precision of the result values.')
     description: str = Field(None, description='Dataset description.')
     product_description: str = Field(None, description='Overall description of the product if method is simulation.')
-    processing_code: int = Field(None, description='The processing code to determine how the input data should be processed.')
+    processing_code: conint(gt=0, lt=7) = Field(None, description='The processing code to determine how the input data should be processed.')
     parent_datasets: List[str] = Field(None, description='The parent datasets that this dataset was derived from.')
     properties: Dict = Field(None, description='Any additional dataset specific properties.')
     modified_date: datetime = Field(None, description='The modification date of the last edit.')
-    version: int = Field(None, description='The version of the metadata structure.')
+    version: conint(gt=1) = Field(None, description='The version of the metadata structure.')
     chunk_parameters: ChunkParams
 
     class Config:
@@ -227,7 +228,7 @@ class ChunkID(BaseModel):
     """
     Model to define the hashing dict to create the chunk_id.
     """
-    heights_index: conint(ge=0) = Field(None, description='The index location (starting with 0) of the heights array of the results. Should be omitted if the chunk should include all heights.')
+    heights_index: List[conint(ge=0)] = Field(None, description='The index locations (starting with 0) of the heights array of the results. Should be omitted if the chunk should include all heights.')
     start_date: conint(ge=-106751, le=106751) = Field(None, description='The start date of the interval for this chunk. The start date is the unix days after 1970-01-01. Can be negative for times before 1970. Should be omitted if the chunk should include all times.')
 
     class Config:
