@@ -39,7 +39,8 @@ key_patterns = {2: {
                     'stations': 'tethys/v4/{dataset_id}.stations.json.zst',
                     'station': 'tethys/v4/{dataset_id}/{station_id}.station.json.zst',
                     'dataset': 'tethys/v4/{dataset_id}.dataset.json.zst',
-                    'results_versions': 'tethys/v4/{dataset_id}.results_versions.json.zst'
+                    'results_versions': 'tethys/v4/{dataset_id}.results_versions.json.zst',
+                    'diagnostics': 'tethys/v4/diagnostics/{project_id}/{run_date}.json.zst'
                     }
                 }
 
